@@ -39,7 +39,7 @@ public:
     };
 
 
-    KAccountsUiPlugin(QObject *parent = 0);
+    KAccountsUiPlugin(QObject *parent = nullptr);
     virtual ~KAccountsUiPlugin();
 
     virtual void init(UiType type) = 0;
@@ -94,7 +94,7 @@ Q_SIGNALS:
     /**
      * Emitted when there has been an error during the authentication
      *
-     * @param errorString The error that has occured
+     * @param errorString The error that has occurred
      */
     void error(const QString &errorString);
 };
